@@ -114,12 +114,6 @@ plot3g <- function(x)
             pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
             switch(pick, plot1g(x), plot2g(x), plot3g(x))
           }
-        else
-          {
-            plot1g(x)
-            plot2g(x)
-            plot3g(x)
-          }
  
   }
   
\ No newline at end of file
