@@ -289,18 +289,6 @@ plot10 <- function(x)
                 pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
                 switch(pick, plot1(x), plot2(x), plot3(x), plot4(x), plot5(x), plot6(x), plot7(x), plot10(x), plot8(x))
               }
-            else
-              {
-                plot1(x)
-                plot2(x)
-                plot3(x)
-                plot4(x)
-                plot5(x)
-                plot6(x)
-                plot7(x)
-                plot10(x)
-                plot8(x)
-              }
           }
         else
           {
@@ -313,18 +301,6 @@ plot10 <- function(x)
                 pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
                 switch(pick, plot1(x), plot2(x), plot3(x), plot4(x), plot5(x), plot6(x), plot7(x), plot10(x), plot9(x))
               }
-            else
-              {
-                plot1(x)
-                plot2(x)
-                plot3(x)
-                plot4(x)
-                plot5(x)
-                plot6(x)
-                plot7(x)
-                plot10(x)
-                plot9(x)
-              }
           }
       }
     
@@ -338,16 +314,6 @@ plot10 <- function(x)
              pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
              switch(pick, plot1(x), plot2(x), plot3(x), plot4(x), plot6(x), plot7(x), plot10(x))
            }
-         else
-          {
-            plot1(x)
-            plot2(x)
-            plot3(x)
-            plot4(x)
-            plot6(x)
-            plot7(x)
-            plot10(x)
-          }
       }
 
   }
