@@ -184,13 +184,6 @@ if (x$models[[1]][[1]]$parameters[4]=="DMA")
             pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
             switch(pick, plot1g(x), plot2g(x), plot3g(x), plot4g(x))
           }
-        else
-          {
-            plot1g(x)
-            plot2g(x)
-            plot3g(x)
-            plot4g(x)
-          }
       }
 else
       {
@@ -201,12 +194,6 @@ else
             pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
             switch(pick, plot1g(x), plot2g(x), plot4g(x))
           }
-        else
-          {
-            plot1g(x)
-            plot2g(x)
-            plot4g(x)
-          }
       }
 
  
