@@ -4,7 +4,7 @@ print.reg <- function(x, ...)
    cat("Mean coefficients: ")
    c <- colMeans(x$coeff.,na.rm=TRUE)
    cat("\n")
-   print(round(c,digits=4))
+   print(round(c,digits=4),quote=FALSE)
    cat("\n")
    e <- (mean((as.vector(x$y)-as.vector(x$y.hat))^2,na.rm=TRUE))^0.5
    e <- round(e,digits=4)
@@ -15,4 +15,5 @@ print.reg <- function(x, ...)
    cat("MAE:  ",e)
    cat("\n")
    if (! is.null(x$window)) { cat("rolling window: ",x$window) }
+   cat("\n")
   }
