@@ -4,7 +4,7 @@ print.tvp <- function(x, ...)
    cat("Mean coefficients: ")
    c <- colMeans(x$thetas,na.rm=TRUE)
    cat("\n")
-   print(round(c,digits=4))
+   print(round(c,digits=4),quote=FALSE)
    cat("\n")
    e <- (mean((as.vector(x$y)-as.vector(x$y.hat))^2,na.rm=TRUE))^0.5
    e <- round(e,digits=4)
@@ -13,4 +13,5 @@ print.tvp <- function(x, ...)
    e <- mean(abs(as.vector(x$y)-as.vector(x$y.hat)),na.rm=TRUE)
    e <- round(e,digits=4)
    cat("MAE:  ",e)
+   cat("\n")
   }
