@@ -5,7 +5,7 @@ summary.tvp <- function(object, ...)
    cat("Mean coefficients: ")
    c <- colMeans(x$thetas,na.rm=TRUE)
    cat("\n")
-   print(round(c,digits=4))
+   print(round(c,digits=4),quote=FALSE)
    cat("\n")
    e <- (mean((as.vector(x$y)-as.vector(x$y.hat))^2,na.rm=TRUE))^0.5
    e <- round(e,digits=4)
